print

Function print 

pub fn print(doc: &CstDocument) -> String
Print a CstDocument back to source text by concatenating all token text.

For an unmodified tree the result equals the original source bytes exactly.