pub enum SyntaxElement {
Node(SyntaxNode),
Token(SyntaxToken),
}Expand description
Either a SyntaxNode or a SyntaxToken — a child element in source order.
Variants
Implementations
Sourceimpl SyntaxElement
impl SyntaxElement
Sourcepub fn kind(&self) -> SyntaxKind
pub fn kind(&self) -> SyntaxKind
This element’s classification (node or token kind).
Sourcepub fn text_range(&self) -> TextRange
pub fn text_range(&self) -> TextRange
Absolute byte range spanned by this element.
Sourcepub fn as_node(&self) -> Option<&SyntaxNode>
pub fn as_node(&self) -> Option<&SyntaxNode>
Borrow as a node, if this element is a node.
Sourcepub fn as_token(&self) -> Option<&SyntaxToken>
pub fn as_token(&self) -> Option<&SyntaxToken>
Borrow as a token, if this element is a token.