pub struct TextRange { /* private fields */ }Expand description
A half-open byte range [start, end) into the original source.
This is ronin-core’s own range type so no rowan type leaks across the API
boundary (INV-7). Offsets are absolute byte offsets into the accepted UTF-8
source.
Implementations