#[non_exhaustive]pub enum BlockedReason {
RenameCollision,
TargetNotFound,
InvalidPayload,
}Expand description
Why a StructuralOp was TransformOutcome::Blocked.
A Blocked outcome guarantees the input CST is unchanged (FR-003, I).
#[non_exhaustive] so future block reasons can be added without a breaking
change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RenameCollision
A rename would collide with an existing field/key in the same struct/map.
TargetNotFound
The addressed parent / element could not be located in the document (e.g. an out-of-range index, or a node from a different tree).
InvalidPayload
The op is not valid for the addressed node (e.g. an op that needs a struct applied to a list element, or new payload text that does not parse).