#[non_exhaustive]pub enum TransformOutcome {
Applied(CstDocument),
Blocked(BlockedReason),
}Expand description
The result of applying a StructuralOp.
#[non_exhaustive] so additional outcome arms can be added without a breaking
change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Applied(CstDocument)
The op applied; carries the new document (untouched regions byte-identical).
Blocked(BlockedReason)
The op was rejected; the input document is unchanged and no edit was made.