pub fn print(doc: &CstDocument) -> StringExpand description
Print a CstDocument back to source text by concatenating all token text.
For an unmodified tree the result equals the original source bytes exactly.
pub fn print(doc: &CstDocument) -> StringPrint a CstDocument back to source text by concatenating all token text.
For an unmodified tree the result equals the original source bytes exactly.